@@ -3,7 +3,7 @@
  * config.h
  *	  load/save configuration
  *
- * Portions Copyright (c) 2017-2025 Pavel Stehule
+ * Portions Copyright (c) 2017-2026 Pavel Stehule
  *
  * IDENTIFICATION
  *	  src/config.h
@@ -107,7 +107,7 @@ typedef struct
 	bool	direct_color;
 } Options;
 
-extern bool save_config(char *path, Options *opts);
-extern bool load_config(char *path, Options *opts);
+extern bool save_config(const char *path, Options *opts);
+extern bool load_config(FILE *cf, Options *opts);
 
 #endif
